@@ -90,7 +90,7 @@ class Application(BaseModel):
     created_at: str
     payment_data: APaymentData
     applicant: Applicant = Field(alias='data')
-    locale: str
+    locale: str = None
     event_version: str
     event_id: UUID
 
