@@ -52,6 +52,7 @@ class PaymentStatus(Enum):
     STATUS_NOTIFICATION_PENDING = 'NOTIFICATION_PENDING'
     STATUS_COMPLETE = 'COMPLETE'
     STATUS_EXPIRED = 'EXPIRED'
+    STATUS_CANCELED = 'CANCELED'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -134,6 +135,14 @@ class Receipt(OnlinePaymentBegin):
     pass
 
 
+class Confirm(OnlinePaymentBegin):
+    pass
+
+
+class Cancel(OnlinePaymentBegin):
+    pass
+
+
 class Notify(BaseModel):
     url: Optional[str]
     method: Optional[HttpMethodType]
@@ -173,6 +182,8 @@ class Links(BaseModel):
     receipt: Receipt
     notify: Optional[List[Notify]]
     update: Update
+    confirm: Confirm
+    cancel: Cancel
 
     class Config:
         validate_all = True
