@@ -164,6 +164,8 @@ def get_payment_event_data(**kwargs):
                 },
             ],
             'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
+            'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
+            'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
         },
         'payer': {
             'type': 'human',
@@ -283,6 +285,8 @@ def get_links_data(**kwargs):
             },
         ],
         'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
+        'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
+        'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'POST'},
         **kwargs,
     }
 
